@@ -2,7 +2,7 @@ import numpy as np
 from torch.utils.data import Dataset
 
 
-class Generic_Dataset(Dataset):
+class GenericDataset(Dataset):
     """
     Class that turns numpy arrays into a torch dataset
 
@@ -18,7 +18,6 @@ class Generic_Dataset(Dataset):
     def __len__(self):
         return len(self.views[0])
 
-    def __getitem__(self, idx):
-        views = [view[idx].astype(np.float32) for view in self.views]
-        return {"views": views,
-                "index": idx}
+    def __getitem__(self, index):
+        views = [view[index].astype(np.float32) for view in self.views]
+        return {"views": views, "index": index}
